@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play the tabla!
 
-our $VERSION = '0.0405';
+our $VERSION = '0.0500';
 
 use Moo;
 use File::ShareDir qw(dist_dir);
@@ -30,14 +30,20 @@ has patches => (
     is      => 'ro',
     default => sub {
         {
-            dhun => [qw(67 80)],
-            ge   => [qw(65 66 76)],
+            # single strikes
+            ga   => [qw(65)],
+            ge   => [qw(66 76)],
             ke   => [qw(64 77 79)],
             na   => [qw(78 81)],
-            ta   => [qw(71 75 85 88)],
+            ta   => [qw(71 75 85)],
             ti   => [qw(61 68 70 72 82 86)],
             tin  => [qw(60 63 83 87)],
-            tun  => [qw(73)],
+            tun  => [qw(88)],
+            # double strikes
+            dha  => [qw(ge ta)],
+            dhin => [qw(ge tin)],
+            dhit => [qw(ge ti)],
+            dhun => [qw(ge tun)],
         }
     },
 );
@@ -58,6 +64,20 @@ sub strike {
     $self->note($dura, $patch);
 }
 
+
+sub double_strike {
+  my ($self, $bol, $dura, $baya, $daya) = @_;
+    $dura ||= $self->quarter;
+    my $bols = $self->patches->{$bol};
+    my $patches = $self->patches->{ $bols->[0] };
+    $baya = $patches->[ int rand @$patches ]
+        if $patches && (!defined $baya || $baya < 0);
+    $patches = $self->patches->{ $bols->[1] };
+    $daya = $patches->[ int rand @$patches ]
+        if $patches && (!defined $daya || $daya < 0);
+    $self->note($dura, $baya, $daya);
+}
+
 1;
 
 __END__
@@ -72,7 +92,7 @@ Music::Percussion::Tabla - Play the tabla!
 
 =head1 VERSION
 
-version 0.0405
+version 0.0500
 
 =head1 SYNOPSIS
 
@@ -91,6 +111,7 @@ version 0.0405
     $t->strike('ge');
     $t->rest($t->quarter);
   }
+  $t->dha($t->quarter, 65, 61);
 
   $t->play_with_timidity;
   # OR:
@@ -163,14 +184,14 @@ Each bol can be 1 or more patch numbers.
 
 Default bol patches:
 
-  dhun: 67 80
-  ge:   65 66 76
+  ga:   65
+  ge:   66 76
   ke:   64 77 79
   na:   78 81
-  ta:   71 75 85 88
+  ta:   71 75 85
   ti:   61 68 70 72 82 86
   tin:  60 63 83 87
-  tun:  73
+  tun:  88
 
 =head1 METHODS
 
@@ -185,13 +206,13 @@ constructor attributes of L<MIDI::Drummer::Tiny>.
 
 =head2 strike
 
-  $tabla->strike('dhun');
-  $tabla->strike('ge', $duration);
-  $tabla->strike('ti', $duration, $patch);
+  $tabla->strike($bol);
+  $tabla->strike($bol, $duration);
+  $tabla->strike($bol, $duration, $patch);
 
-Bols:
+Single strike bols:
 
-  dhun, ge, ke, na, ta, ti, tin, tun
+  ga, ge, ke, na, ta, ti, tin, tun
 
 The B<duration> is a note length like C<$tabla-E<gt>eighth> (or
 C<'en'> in MIDI-Perl notation).
@@ -200,6 +221,18 @@ Each bol can be 1 or more patch numbers. For bols with more than one
 patch possibility, calling that method with either no B<patch> or a
 B<patch> of C<-1> will play one of the patches at random.
 
+=head2 double_strike
+
+  $tabla->double_strike($bol);
+  $tabla->double_strike($bol, $duration);
+
+Double strike bols:
+
+  dha, dhin, dhit, dhun
+
+Play a double-strike on the B<baya> and B<daya> drums for the given
+B<bol> and B<duration>.
+
 =head1 SEE ALSO
 
 The F<t/01-methods.t> and F<eg/*> programs in this distribution.
